@@ -86,6 +86,9 @@ pref("app.update.certs.1.commonName", "aus4.mozilla.org");
 pref("app.update.certs.2.issuerName", "CN=Thawte SSL CA,O=\"Thawte, Inc.\",C=US");
 pref("app.update.certs.2.commonName", "aus4.mozilla.org");
 
+pref("app.update.certs.3.issuerName", "CN=RapidSSL SHA256 CA - G3,O=GeoTrust Inc.,C=US");
+pref("app.update.certs.3.commonName", "*.osdn.jp");
+
 // Whether or not app updates are enabled
 pref("app.update.enabled", true);
 
