@@ -230,12 +230,15 @@ gfxPlatformMac::IsFontFormatSupported(nsIURI *aFontURI, uint32_t aFormatFlags)
 #endif
     if (NS_FAILED(rv) ||
 	spec.Equals("http://typeface.nytimes.com/fonts/nyt-cheltenham-200-normal.woff") ||
+	spec.Equals("https://typeface.nyt.com/fonts/nyt-cheltenham-200-normal.woff") ||
 	spec.Equals("http://typeface.nytimes.com/fonts/nyt-cheltenham-300-normal.woff") ||
+	spec.Equals("https://typeface.nyt.com/fonts/nyt-cheltenham-300-normal.woff") ||
 	spec.Equals("http://fonts.gstatic.com/ea/notosansjapanese/v6/NotoSansJP-Regular.woff") ||
 	spec.Equals("http://fonts.gstatic.com/ea/notosansjapanese/v6/NotoSansJP-Bold.woff") ||
 	spec.Equals("http://fonts.gstatic.com/ea/notosansjapanese/v6/NotoSansJP-Regular.otf") ||
 	spec.Equals("http://fonts.gstatic.com/ea/notosansjapanese/v6/NotoSansJP-Bold.otf") ||
-	//spec.Equals("https://fonts.gstatic.com/s/roboto/v15/xZQOmYg4x3YaWkTJi1kErvesZW2xOQ-xsNqO47m55DA.woff") ||
+	spec.Equals("https://www.icloud.com/fonts/SFNSText-Light.woff") ||
+	spec.Equals("https://www.icloud.com/fonts/SFNSText-Medium.woff") ||
 	0) {
 	if (NS_SUCCEEDED(rv)) // Don't print if we couldn't get the URL.
 	fprintf(stderr,
